# mypy-boto3-greengrassv2<a id="mypy-boto3-greengrassv2"></a>

[![PyPI - mypy-boto3-greengrassv2](https://img.shields.io/pypi/v/mypy-boto3-greengrassv2.svg?color=blue)](https://pypi.org/project/mypy-boto3-greengrassv2)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/mypy-boto3-greengrassv2.svg?color=blue)](https://pypi.org/project/mypy-boto3-greengrassv2)
[![Docs](https://img.shields.io/readthedocs/mypy-boto3-builder.svg?color=blue)](https://mypy-boto3-builder.readthedocs.io/)
[![PyPI - Downloads](https://img.shields.io/pypi/dw/mypy-boto3-greengrassv2?color=blue)](https://pypistats.org/packages/mypy-boto3-greengrassv2)

![boto3.typed](https://github.com/vemel/mypy_boto3_builder/raw/master/logo.png)

Type annotations for
[boto3.GreengrassV2 1.17.71](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/greengrassv2.html#GreengrassV2)
service compatible with [VSCode](https://code.visualstudio.com/),
[PyCharm](https://www.jetbrains.com/pycharm/),
[Emacs](https://www.gnu.org/software/emacs/),
[Sublime Text](https://www.sublimetext.com/),
[mypy](https://github.com/python/mypy),
[pyright](https://github.com/microsoft/pyright) and other tools.

Generated by
[mypy-boto3-buider 4.12.0](https://github.com/vemel/mypy_boto3_builder).

More information can be found on
[boto3-stubs](https://pypi.org/project/boto3-stubs/) page and in
[mypy-boto3-greengrassv2 docs](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_greengrassv2/)

See how it helps to find and fix potential bugs:

![boto3-stubs demo](https://github.com/vemel/mypy_boto3_builder/raw/master/demo.gif)

- [mypy-boto3-greengrassv2](#mypy-boto3-greengrassv2)
  - [How to install](#how-to-install)
  - [Usage](#usage)
    - [VSCode](#vscode)
    - [PyCharm](#pycharm)
    - [Other IDEs](#other-ides)
    - [mypy](#mypy)
    - [pyright](#pyright)
  - [Explicit type annotations](#explicit-type-annotations)
    - [Client annotations](#client-annotations)
    - [Paginators annotations](#paginators-annotations)
    - [Literals](#literals)
    - [Typed dictionaries](#typed-dictionaries)
  - [Versioning](#versioning)
  - [Documentation](#documentation)
  - [Support and contributing](#support-and-contributing)

## How to install<a id="how-to-install"></a>

Install `boto3-stubs` for `GreengrassV2` service.

```bash
python -m pip install boto3-stubs[greengrassv2]
```

## Usage<a id="usage"></a>

### VSCode<a id="vscode"></a>

- Install
  [Python extension](https://marketplace.visualstudio.com/items?itemName=ms-python.python)
- Install
  [Pylance extension](https://marketplace.visualstudio.com/items?itemName=ms-python.vscode-pylance)
- Set `Pylance` as your Python Language Server
- Install `boto-stubs[greengrassv2]` in your environment:
  `python -m pip install 'boto3-stubs[greengrassv2]'`

Both type checking and auto-complete should work for `GreengrassV2` service. No
explicit type annotations required, write your `boto3` code as usual.

### PyCharm<a id="pycharm"></a>

- Install `boto-stubs[greengrassv2]` in your environment:
  `python -m pip install 'boto3-stubs[greengrassv2]'`

Both type checking and auto-complete should work for `GreengrassV2` service. No
explicit type annotations required, write your `boto3` code as usual.
Auto-complete can be slow on big projects or if you have a lot of installed
`boto3-stubs` submodules.

### Other IDEs<a id="other-ides"></a>

Not tested, but as long as your IDE support `mypy` or `pyright`, everything
should work.

### mypy<a id="mypy"></a>

- Install `mypy`: `python -m pip install mypy`
- Install `boto-stubs[greengrassv2]` in your environment:
  `python -m pip install 'boto3-stubs[greengrassv2]'`
- Run `mypy` as usual

Type checking should work for `GreengrassV2` service. No explicit type
annotations required, write your `boto3` code as usual.

### pyright<a id="pyright"></a>

- Install `pyright`: `yarn global add pyright`
- Install `boto-stubs[greengrassv2]` in your environment:
  `python -m pip install 'boto3-stubs[greengrassv2]'`
- Optionally, you can install `boto3-stubs` to `typings` folder.

Type checking should work for `GreengrassV2` service. No explicit type
annotations required, write your `boto3` code as usual.

## Explicit type annotations<a id="explicit-type-annotations"></a>

### Client annotations<a id="client-annotations"></a>

`GreengrassV2Client` provides annotations for `boto3.client("greengrassv2")`.

```python
import boto3

from mypy_boto3_greengrassv2 import GreengrassV2Client

client: GreengrassV2Client = boto3.client("greengrassv2")

# now client usage is checked by mypy and IDE should provide code auto-complete

# works for session as well
session = boto3.session.Session(region="us-west-1")
session_client: GreengrassV2Client = session.client("greengrassv2")
```

### Paginators annotations<a id="paginators-annotations"></a>

`mypy_boto3_greengrassv2.paginator` module contains type annotations for all
paginators.

```python
from mypy_boto3_greengrassv2 import GreengrassV2Client
from mypy_boto3_greengrassv2.paginator import (
    ListComponentVersionsPaginator,
    ListComponentsPaginator,
    ListCoreDevicesPaginator,
    ListDeploymentsPaginator,
    ListEffectiveDeploymentsPaginator,
    ListInstalledComponentsPaginator,
)

client: GreengrassV2Client = boto3.client("greengrassv2")

# Explicit type annotations are optional here
# Type should be correctly discovered by mypy and IDEs
# VSCode requires explicit type annotations
list_component_versions_paginator: ListComponentVersionsPaginator = client.get_paginator("list_component_versions")
list_components_paginator: ListComponentsPaginator = client.get_paginator("list_components")
list_core_devices_paginator: ListCoreDevicesPaginator = client.get_paginator("list_core_devices")
list_deployments_paginator: ListDeploymentsPaginator = client.get_paginator("list_deployments")
list_effective_deployments_paginator: ListEffectiveDeploymentsPaginator = client.get_paginator("list_effective_deployments")
list_installed_components_paginator: ListInstalledComponentsPaginator = client.get_paginator("list_installed_components")
```

### Literals<a id="literals"></a>

`mypy_boto3_greengrassv2.literals` module contains literals extracted from
shapes that can be used in user code for type checking.

```python
from mypy_boto3_greengrassv2.literals import (
    CloudComponentState,
    ComponentDependencyType,
    ComponentVisibilityScope,
    CoreDeviceStatus,
    DeploymentComponentUpdatePolicyAction,
    DeploymentFailureHandlingPolicy,
    DeploymentHistoryFilter,
    DeploymentStatus,
    EffectiveDeploymentExecutionStatus,
    InstalledComponentLifecycleState,
    IoTJobAbortAction,
    IoTJobExecutionFailureType,
    LambdaEventSourceType,
    LambdaFilesystemPermission,
    LambdaInputPayloadEncodingType,
    LambdaIsolationMode,
    ListComponentVersionsPaginatorName,
    ListComponentsPaginatorName,
    ListCoreDevicesPaginatorName,
    ListDeploymentsPaginatorName,
    ListEffectiveDeploymentsPaginatorName,
    ListInstalledComponentsPaginatorName,
    RecipeOutputFormat,
)

def check_value(value: CloudComponentState) -> bool:
    ...
```

### Typed dictionaries<a id="typed-dictionaries"></a>

`mypy_boto3_greengrassv2.type_defs` module contains structures and shapes
assembled to typed dictionaries for additional type checking.

```python
from mypy_boto3_greengrassv2.type_defs import (
    CancelDeploymentResponseTypeDef,
    CloudComponentStatusTypeDef,
    ComponentCandidateTypeDef,
    ComponentConfigurationUpdateTypeDef,
    ComponentDependencyRequirementTypeDef,
    ComponentDeploymentSpecificationTypeDef,
    ComponentLatestVersionTypeDef,
    ComponentPlatformTypeDef,
    ComponentRunWithTypeDef,
    ComponentTypeDef,
    ComponentVersionListItemTypeDef,
    CoreDeviceTypeDef,
    CreateComponentVersionResponseTypeDef,
    CreateDeploymentResponseTypeDef,
    DeploymentComponentUpdatePolicyTypeDef,
    DeploymentConfigurationValidationPolicyTypeDef,
    DeploymentIoTJobConfigurationTypeDef,
    DeploymentPoliciesTypeDef,
    DeploymentTypeDef,
    DescribeComponentResponseTypeDef,
    EffectiveDeploymentTypeDef,
    GetComponentResponseTypeDef,
    GetComponentVersionArtifactResponseTypeDef,
    GetCoreDeviceResponseTypeDef,
    GetDeploymentResponseTypeDef,
    InstalledComponentTypeDef,
    IoTJobAbortConfigTypeDef,
    IoTJobAbortCriteriaTypeDef,
    IoTJobExecutionsRolloutConfigTypeDef,
    IoTJobExponentialRolloutRateTypeDef,
    IoTJobRateIncreaseCriteriaTypeDef,
    IoTJobTimeoutConfigTypeDef,
    LambdaContainerParamsTypeDef,
    LambdaDeviceMountTypeDef,
    LambdaEventSourceTypeDef,
    LambdaExecutionParametersTypeDef,
    LambdaFunctionRecipeSourceTypeDef,
    LambdaLinuxProcessParamsTypeDef,
    LambdaVolumeMountTypeDef,
    ListComponentVersionsResponseTypeDef,
    ListComponentsResponseTypeDef,
    ListCoreDevicesResponseTypeDef,
    ListDeploymentsResponseTypeDef,
    ListEffectiveDeploymentsResponseTypeDef,
    ListInstalledComponentsResponseTypeDef,
    ListTagsForResourceResponseTypeDef,
    PaginatorConfigTypeDef,
    ResolveComponentCandidatesResponseTypeDef,
    ResolvedComponentVersionTypeDef,
)

def get_structure() -> CancelDeploymentResponseTypeDef:
    return {
      ...
    }
```

## Versioning<a id="versioning"></a>

`mypy-boto3-greengrassv2` version is the same as related `boto3` version and
follows [PEP 440](https://www.python.org/dev/peps/pep-0440/) format.

## Documentation<a id="documentation"></a>

All type annotations can be found in
[mypy-boto3-greengrassv2 docs](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_greengrassv2/)

## Support and contributing<a id="support-and-contributing"></a>

This package is auto-generated. Please reports any bugs or request new features
in [mypy-boto3-builder](https://github.com/vemel/mypy_boto3_builder/issues/)
repository.
